@@ -440,7 +440,7 @@ def sessions_transforms(sessions, ramps, access_groups, devices):
     sessions.loc[sessions['Access Group'].isna(), 'Access Group'] = None
 
     # LANE
-    sessions['Lane'] = pd.to_numeric(sessions['Qtg_tcc_num']).astype('Int64').map(lanes)
+    sessions['Lane'] = sessions['Qtg_tcc_num'].map(lanes)
 
     # REVENUE
     sessions['Revenue'] = pd.to_numeric(sessions['Qtg_bet_brutto']) / 100
